package com.ruoyi.warehouseBusiness.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.warehouseBusiness.domain.TWarehousebillsCntrLogger;
import com.ruoyi.warehouseBusiness.mapper.TWarehousebillsCntrLoggerMapper;
import com.ruoyi.warehouseBusiness.service.ITWarehousebillsCntrLoggerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 凯和订单从(修改记录)Service业务层处理
 * 
 * @author ruoyi
 * @date 2021-07-05
 */
@Service
public class TWarehousebillsCntrLoggerServiceImpl implements ITWarehousebillsCntrLoggerService
{
    @Autowired
    private TWarehousebillsCntrLoggerMapper tWarehousebillsCntrLoggerMapper;

    /**
     * 查询凯和订单从(修改记录)
     * 
     * @param fId 凯和订单从(修改记录)ID
     * @return 凯和订单从(修改记录)
     */
    @Override
    public TWarehousebillsCntrLogger selectTWarehousebillsCntrLoggerById(Long fId)
    {
        return tWarehousebillsCntrLoggerMapper.selectTWarehousebillsCntrLoggerById(fId);
    }

    /**
     * 查询凯和订单从(修改记录)列表
     * 
     * @param tWarehousebillsCntrLogger 凯和订单从(修改记录)
     * @return 凯和订单从(修改记录)
     */
    @Override
    public List<TWarehousebillsCntrLogger> selectTWarehousebillsCntrLoggerList(TWarehousebillsCntrLogger tWarehousebillsCntrLogger)
    {
        return tWarehousebillsCntrLoggerMapper.selectTWarehousebillsCntrLoggerList(tWarehousebillsCntrLogger);
    }

    /**
     * 新增凯和订单从(修改记录)
     * 
     * @param tWarehousebillsCntrLogger 凯和订单从(修改记录)
     * @return 结果
     */
    @Override
    public int insertTWarehousebillsCntrLogger(TWarehousebillsCntrLogger tWarehousebillsCntrLogger)
    {
        tWarehousebillsCntrLogger.setCreateTime(DateUtils.getNowDate());
        return tWarehousebillsCntrLoggerMapper.insertTWarehousebillsCntrLogger(tWarehousebillsCntrLogger);
    }

    /**
     * 修改凯和订单从(修改记录)
     * 
     * @param tWarehousebillsCntrLogger 凯和订单从(修改记录)
     * @return 结果
     */
    @Override
    public int updateTWarehousebillsCntrLogger(TWarehousebillsCntrLogger tWarehousebillsCntrLogger)
    {
        tWarehousebillsCntrLogger.setUpdateTime(DateUtils.getNowDate());
        return tWarehousebillsCntrLoggerMapper.updateTWarehousebillsCntrLogger(tWarehousebillsCntrLogger);
    }

    /**
     * 批量删除凯和订单从(修改记录)
     * 
     * @param fIds 需要删除的凯和订单从(修改记录)ID
     * @return 结果
     */
    @Override
    public int deleteTWarehousebillsCntrLoggerByIds(Long[] fIds)
    {
        return tWarehousebillsCntrLoggerMapper.deleteTWarehousebillsCntrLoggerByIds(fIds);
    }

    /**
     * 删除凯和订单从(修改记录)信息
     * 
     * @param fId 凯和订单从(修改记录)ID
     * @return 结果
     */
    @Override
    public int deleteTWarehousebillsCntrLoggerById(Long fId)
    {
        return tWarehousebillsCntrLoggerMapper.deleteTWarehousebillsCntrLoggerById(fId);
    }
}
