package com.ruoyi.web.controller.warehouse.warehouseBusiness;

import java.util.List;

import com.ruoyi.warehouseBusiness.domain.TWarehousebillsCntrLogger;
import com.ruoyi.warehouseBusiness.service.ITWarehousebillsCntrLoggerService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 凯和订单从(修改记录)Controller
 * 
 * @author ruoyi
 * @date 2021-07-05
 */
@RestController
@RequestMapping("/warehouse/tWarehousebillsCntrLogger")
public class TWarehousebillsCntrLoggerController extends BaseController
{
    @Autowired
    private ITWarehousebillsCntrLoggerService tWarehousebillsCntrLoggerService;

    /**
     * 查询凯和订单从(修改记录)列表
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:list')")
    @GetMapping("/list")
    public TableDataInfo list(TWarehousebillsCntrLogger tWarehousebillsCntrLogger)
    {
        startPage();
        List<TWarehousebillsCntrLogger> list = tWarehousebillsCntrLoggerService.selectTWarehousebillsCntrLoggerList(tWarehousebillsCntrLogger);
        return getDataTable(list);
    }

    /**
     * 导出凯和订单从(修改记录)列表
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:export')")
    @Log(title = "凯和订单从(修改记录)", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TWarehousebillsCntrLogger tWarehousebillsCntrLogger)
    {
        List<TWarehousebillsCntrLogger> list = tWarehousebillsCntrLoggerService.selectTWarehousebillsCntrLoggerList(tWarehousebillsCntrLogger);
        ExcelUtil<TWarehousebillsCntrLogger> util = new ExcelUtil<TWarehousebillsCntrLogger>(TWarehousebillsCntrLogger.class);
        return util.exportExcel(list, "logger");
    }

    /**
     * 获取凯和订单从(修改记录)详细信息
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:query')")
    @GetMapping(value = "/{fId}")
    public AjaxResult getInfo(@PathVariable("fId") Long fId)
    {
        return AjaxResult.success(tWarehousebillsCntrLoggerService.selectTWarehousebillsCntrLoggerById(fId));
    }

    /**
     * 新增凯和订单从(修改记录)
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:add')")
    @Log(title = "凯和订单从(修改记录)", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TWarehousebillsCntrLogger tWarehousebillsCntrLogger)
    {
        return toAjax(tWarehousebillsCntrLoggerService.insertTWarehousebillsCntrLogger(tWarehousebillsCntrLogger));
    }

    /**
     * 修改凯和订单从(修改记录)
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:edit')")
    @Log(title = "凯和订单从(修改记录)", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TWarehousebillsCntrLogger tWarehousebillsCntrLogger)
    {
        return toAjax(tWarehousebillsCntrLoggerService.updateTWarehousebillsCntrLogger(tWarehousebillsCntrLogger));
    }

    /**
     * 删除凯和订单从(修改记录)
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:remove')")
    @Log(title = "凯和订单从(修改记录)", businessType = BusinessType.DELETE)
	@DeleteMapping("/{fIds}")
    public AjaxResult remove(@PathVariable Long[] fIds)
    {
        return toAjax(tWarehousebillsCntrLoggerService.deleteTWarehousebillsCntrLoggerByIds(fIds));
    }
}
